@@ -20,7 +20,7 @@ class QiYuSSOAsync(BaseAPI):
         使用 访问令牌 获取用户信息
         """
         r = await self._http.post(
-            url=args.server_uri, json={"access_token": args.access_token}
+            url=args.server_uri, json=args.dict(exclude={"server_uri"})
         )
         if not r.ok:
             logging.error(f"get user info failed: {r}")
